@@ -33,7 +33,7 @@ TEST_DATA_SHUTTER = {
     'read_only': 'no'
 }
 
-TEST_DATA_GARAGE = {
+TEST_DATA_DOOR = {
     'title': 'Garage door',
     'id': 'GARAGE_DOOR',
     'read_only': 'no'
@@ -61,6 +61,26 @@ TEST_RESOURCE_SWITCH = {
     'type': 'switch'
 }
 
+TEST_SHUTTER_UP = "ZAL__ahor"
+TEST_SHUTTER_DOWN = "Z_Obk_do"
+TEST_SHUTTER_ID = f"{TEST_SHUTTER_UP}_{TEST_SHUTTER_DOWN}"
+TEST_SHUTTER_NAME = "Zal OB"
+
+TEST_RETURN_RESOURCE_SHUTTER = {
+    f'{TEST_SHUTTER_DOWN}': 0,
+    f'{TEST_SHUTTER_UP}': 0
+}
+
+TEST_RETURN_RESOURCE_SHUTTER_UP = {
+    f'{TEST_SHUTTER_DOWN}': 0,
+    f'{TEST_SHUTTER_UP}': 1
+}
+
+TEST_RETURN_RESOURCE_SHUTTER_DOWN = {
+    f'{TEST_SHUTTER_DOWN}': 1,
+    f'{TEST_SHUTTER_UP}': 0
+}
+
 TEST_RAW_LIGHT = """
 lights:
 name="Main light" column="0" inels="SV_12_Garage" read_only="no" row="0"
@@ -76,6 +96,11 @@ garage:
 name="Vrata" column="0" inels="Vrata_Garaz" read_only="no" row="1"
 """
 
+TEST_RAW_SHUTTER = """
+shutters:
+name="Zal OB" column="0" down="Z_Obk_do" read_only="no" up="ZAL__ahor" row="3"
+"""
+
 TEST_RAW_DUPLICIT_DEVICES = """on_off:
 name="Zas OB" column="0" inels="ZAS_1A_Obyvak" read_only="no" row="2"
 name="Zas POK" column="1" inels="ZAS_1B_Pokoj_dole" read_only="no" row="2"
